Package: ReliaPlotR
Type: Package
Title: Interactive Reliability Probability Plots
Version: 0.7
Authors@R: person("Paul", "Govan", email = "paul.govan2@gmail.com", role = c("aut", "cre", "cph"), comment = c(ORCID = "0000-0002-1821-8492"))
Description: Build interactive Reliability Probability Plots with 'plotly' by Carson Sievert (2020) <https://plotly.com/r/>, an interactive web-based graphing library.
URL: https://paulgovan.github.io/ReliaPlotR/,
        https://github.com/paulgovan/ReliaPlotR
BugReports: https://github.com/paulgovan/ReliaPlotR/issues
License: Apache License
Imports: plotly, ReliaGrowR, WeibullR, WeibullR.ALT
Suggests: ellmer, jsonlite, knitr, mcptools, rmarkdown, spelling,
        testthat (>= 3.0.0)
Encoding: UTF-8
RoxygenNote: 7.3.3
VignetteBuilder: knitr
Config/testthat/edition: 3
Language: en-US
NeedsCompilation: no
Packaged: 2026-06-03 20:43:49 UTC; paulgovan
Author: Paul Govan [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0002-1821-8492>)
Maintainer: Paul Govan <paul.govan2@gmail.com>
Repository: CRAN
Date/Publication: 2026-06-04 05:11:36 UTC
Built: R 4.6.0; ; 2026-06-04 08:22:54 UTC; unix
