# Generated by roxygen2: do not edit by hand

export(plotly_alt)
export(plotly_contour)
export(plotly_duane)
export(plotly_exposure)
export(plotly_mcf)
export(plotly_nhpp)
export(plotly_rel)
export(plotly_rga)
export(plotly_wblr)
export(reliapltr_mcp_server)
export(tidy_alt)
export(tidy_rga)
export(tidy_wblr)
import(ReliaGrowR)
import(WeibullR)
import(WeibullR.ALT)
import(plotly)
importFrom(graphics,text)
importFrom(plotly,add_trace)
importFrom(plotly,layout)
importFrom(plotly,plot_ly)
importFrom(plotly,toRGB)
importFrom(stats,coef)
importFrom(stats,plnorm)
importFrom(stats,pweibull)
importFrom(stats,qlnorm)
importFrom(stats,qnorm)
importFrom(stats,qweibull)
importFrom(stats,runif)
